using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.ComponentModel;
using System.Text;

namespace NeoCore.PanelControl {
	/// <summary>
	/// XMSPanelDropDownList extends DropDownList to provide XMSPanelControl functionality
	/// </summary>
	[DefaultProperty("Text"), 
	ToolboxData("<{0}:XMSPanelDropDownList runat=server></{0}:XMSPanelDropDownList>")]
	public class XMSPanelDropDownList : DropDownList, XMSControl {
		//private string text;
		private static string PATH_SEPARATOR = "/";
	
		/// <summary>
		/// ToXML returns the Xml string this control represents
		/// </summary>
		/// <returns>The xml string</returns>
		public string ToXML() {
			StringBuilder sb = new StringBuilder();
			sb.Append( "<" + this.ID + ">" );
			sb.Append( HttpUtility.HtmlEncode(this.SelectedItem.Text) );
			sb.Append( "</" + this.ID + ">" );
			return sb.ToString();
		}

		/// <summary>
		/// SetData sets the data for this control
		/// </summary>
		/// <param name="data">The data to set</param>
		public void SetData(string data) {
			for (int i = 0; i < this.Items.Count; i++) 
				if( this.Items[i].Text.Equals(data) )
					this.SelectedIndex = i;
		}

		/// <summary>
		/// Clear data from the control
		/// </summary>
		public void Clear() {
			this.SelectedIndex = 0;
		}

		/// <summary>
		/// ToXPathPredicate creates a predicate in the form of myName="myValue" and returns that string
		/// </summary>
		/// <param name="prependValue">The which needs to be prepended to the myName to fully represent the path</param>
		/// <returns>The predicate string</returns>
		public string ToXPathPredicate(string prependValue) {
			StringBuilder sb = new StringBuilder();
			if (!this.SelectedItem.Text.Equals("")) {
				sb.Append(prependValue);
				sb.Append("/");
				sb.Append(this.ID);
				sb.Append("=\"");
				sb.Append(this.SelectedItem.Text);
				sb.Append("\"");
			}
			return sb.ToString();
		}
	}
}
